Module problem

Module problem 

RFC 9457 Problem Details for HTTP APIs (pure data model, no HTTP framework dependencies)

Structs

Problem
RFC 9457 Problem Details for HTTP APIs.
ValidationError
Collection of validation errors for 422 responses.
ValidationErrorResponse
Wrapper for ValidationError that can be used as a standalone response.
ValidationViolation
Individual validation violation for a specific field or property.

Constants

APPLICATION_PROBLEM_JSON
Content type for Problem Details as per RFC 9457.