Problem

Struct Problem 

pub struct Problem {
    pub type_url: String,
    pub title: String,
    pub status: StatusCode,
    pub detail: String,
    pub instance: String,
    pub code: String,
    pub trace_id: Option<String>,
    pub errors: Option<Vec<ValidationViolation>>,
}
RFC 9457 Problem Details for HTTP APIs.

Fields

type_url: String

A URI reference that identifies the problem type. When dereferenced, it might provide human-readable documentation.

title: String

A short, human-readable summary of the problem type.

status: StatusCode

The HTTP status code for this occurrence of the problem. Serializes as u16 for RFC 9457 compatibility.

detail: String

A human-readable explanation specific to this occurrence of the problem.

instance: String

A URI reference that identifies the specific occurrence of the problem.

code: String

Optional machine-readable error code defined by the application.

trace_id: Option<String>

Optional trace id useful for tracing.

errors: Option<Vec<ValidationViolation>>

Optional validation errors for 4xx problems.

Implementations

Source

impl Problem

pub fn new( status: StatusCode, title: impl Into<String>, detail: impl Into<String>, ) -> Self

Create a new Problem with the given status, title, and detail.

Note: This function accepts http::StatusCode for type safety. The status is serialized as u16 for RFC 9457 compatibility.

pub fn with_type(self, type_url: impl Into<String>) -> Self

pub fn with_instance(self, uri: impl Into<String>) -> Self

pub fn with_code(self, code: impl Into<String>) -> Self

pub fn with_trace_id(self, id: impl Into<String>) -> Self

pub fn with_errors(self, errors: Vec<ValidationViolation>) -> Self